# Miscellaneous Widgets

Utility widgets: animated circular timer, drag & drop list,
option selector, theme-aware icon, toggle icon and modern toggle switch.

---

## CircularTimer

::: ezqt_widgets.misc.circular_timer.CircularTimer

---

## DraggableList

::: ezqt_widgets.misc.draggable_list.DraggableList

---

## DraggableItem

::: ezqt_widgets.misc.draggable_list.DraggableItem

---

## OptionSelector

::: ezqt_widgets.misc.option_selector.OptionSelector

---

## ToggleIcon

::: ezqt_widgets.misc.toggle_icon.ToggleIcon

---

## ToggleSwitch

::: ezqt_widgets.misc.toggle_switch.ToggleSwitch

---

## ThemeIcon

::: ezqt_widgets.misc.theme_icon.ThemeIcon
